cosmpy.protos.cosmos.distribution.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.distribution.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.distribution.v1beta1.distribution_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.distribution.v1beta1.distribution_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.distribution.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.distribution.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.distribution.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.distribution.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.distribution.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service for distribution module.

  static CommunityPool(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegationRewards(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegationTotalRewards(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegatorValidators(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegatorWithdrawAddress(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ValidatorCommission(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ValidatorOutstandingRewards(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ValidatorSlashes(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.distribution.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service for distribution module.

  CommunityPool(request, context)

    CommunityPool queries the community pool coins.

  DelegationRewards(request, context)

    DelegationRewards queries the total rewards accrued by a delegation.

  DelegationTotalRewards(request, context)

    DelegationTotalRewards queries the total rewards accrued by a each validator.

  DelegatorValidators(request, context)

    DelegatorValidators queries the validators of a delegator.

  DelegatorWithdrawAddress(request, context)

    DelegatorWithdrawAddress queries withdraw address of a delegator.

  Params(request, context)

    Params queries params of the distribution module.

  ValidatorCommission(request, context)

    ValidatorCommission queries accumulated commission for a validator.

  ValidatorOutstandingRewards(request, context)

    ValidatorOutstandingRewards queries rewards of a validator address.

  ValidatorSlashes(request, context)

    ValidatorSlashes queries slash events of a validator.

class cosmpy.protos.cosmos.distribution.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service for distribution module.

cosmpy.protos.cosmos.distribution.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.distribution.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.distribution.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.distribution.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the distribution Msg service.

  static FundCommunityPool(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SetWithdrawAddress(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static WithdrawDelegatorReward(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static WithdrawValidatorCommission(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.distribution.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the distribution Msg service.

  FundCommunityPool(request, context)

    FundCommunityPool defines a method to allow an account to directly fund the community pool.

  SetWithdrawAddress(request, context)

    SetWithdrawAddress defines a method to change the withdraw address for a delegator (or validator self-delegation).

  WithdrawDelegatorReward(request, context)

    WithdrawDelegatorReward defines a method to withdraw rewards of delegator from a single validator.

  WithdrawValidatorCommission(request, context)

    WithdrawValidatorCommission defines a method to withdraw the full commission to the validator address.

class cosmpy.protos.cosmos.distribution.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the distribution Msg service.

cosmpy.protos.cosmos.distribution.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents